# Backward-compat shim — moved to openagents.client.workspace_client
from openagents.client.workspace_client import *  # noqa: F401,F403
from openagents.client.workspace_client import _load_identities, _save_identities  # noqa: F401
